"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.deployment.object_pb2
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.service.service_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RecordDeploymentReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    PENDING_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.deployment.object_pb2.DeploymentConfig: ...
    pending: builtins.bool
    """If true, create deployment with pending status that is meant to be updated later to either success or failure.
    By default, deployments are created with status SUCCEEDED.
    """
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.deployment.object_pb2.DeploymentConfig | None = ...,
        pending: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "pending", b"pending"]) -> None: ...

global___RecordDeploymentReq = RecordDeploymentReq

class RecordDeploymentResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta"]) -> None: ...

global___RecordDeploymentResp = RecordDeploymentResp

class UpdateDeploymentStatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    status: prodvana.proto.prodvana.deployment.object_pb2.DeploymentStatus.ValueType
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
        status: prodvana.proto.prodvana.deployment.object_pb2.DeploymentStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "status", b"status"]) -> None: ...

global___UpdateDeploymentStatusReq = UpdateDeploymentStatusReq

class UpdateDeploymentStatusResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: prodvana.proto.prodvana.deployment.object_pb2.DeploymentStatus.ValueType
    def __init__(
        self,
        *,
        status: prodvana.proto.prodvana.deployment.object_pb2.DeploymentStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___UpdateDeploymentStatusResp = UpdateDeploymentStatusResp

class DeploymentFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """filters to deployments for join(join(services, OR), join(release_channels, OR), AND)"""
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    application: builtins.str
    """if set, the filters on services and deployment channels above will be limited to this app.
    Otherwise, there is no app filter (so e.g. release_channels=['staging'] will select
    staging deployment channels across all apps.)
    """
    desired_state_id: builtins.str
    """desired_state_id filter is AND'ed with everything else in the same filter object"""
    release_id: builtins.str
    """release_id filter is AND'ed with everything else in the same filter object"""
    def __init__(
        self,
        *,
        services: collections.abc.Iterable[builtins.str] | None = ...,
        release_channels: collections.abc.Iterable[builtins.str] | None = ...,
        application: builtins.str = ...,
        desired_state_id: builtins.str = ...,
        release_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "desired_state_id", b"desired_state_id", "release_channels", b"release_channels", "release_id", b"release_id", "services", b"services"]) -> None: ...

global___DeploymentFilter = DeploymentFilter

class ListDeploymentsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTERS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    STARTING_DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    ENDING_DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentFilter]:
        """filters for listing deployments. Multiple filters are OR'ed together."""
    @property
    def filter(self) -> global___DeploymentFilter:
        """escape hatch to support openAPI, which cannot handle repeated list of messages on GET requests. This is joined to the filters list with an OR."""
    starting_deployment_id: builtins.str
    """newer deployment, inclusive"""
    ending_deployment_id: builtins.str
    """older deployment, exclusive"""
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        filters: collections.abc.Iterable[global___DeploymentFilter] | None = ...,
        filter: global___DeploymentFilter | None = ...,
        starting_deployment_id: builtins.str = ...,
        ending_deployment_id: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ending_deployment_id", b"ending_deployment_id", "filter", b"filter", "filters", b"filters", "page_size", b"page_size", "page_token", b"page_token", "starting_deployment_id", b"starting_deployment_id"]) -> None: ...

global___ListDeploymentsReq = ListDeploymentsReq

class ListDeploymentsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.deployment.object_pb2.Deployment]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        deployments: collections.abc.Iterable[prodvana.proto.prodvana.deployment.object_pb2.Deployment] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployments", b"deployments", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDeploymentsResp = ListDeploymentsResp

class DeploymentRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ServiceInstanceConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COMPILED_CONFIG_FIELD_NUMBER: builtins.int
        @property
        def compiled_config(self) -> prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig: ...
        def __init__(
            self,
            *,
            compiled_config: prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config"]) -> None: ...

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    @property
    def config(self) -> prodvana.proto.prodvana.deployment.object_pb2.DeploymentConfig: ...
    @property
    def service_instance_config(self) -> global___DeploymentRef.ServiceInstanceConfig: ...
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
        config: prodvana.proto.prodvana.deployment.object_pb2.DeploymentConfig | None = ...,
        service_instance_config: global___DeploymentRef.ServiceInstanceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "deployment_id", b"deployment_id", "ref", b"ref", "service_instance_config", b"service_instance_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "deployment_id", b"deployment_id", "ref", b"ref", "service_instance_config", b"service_instance_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["ref", b"ref"]) -> typing_extensions.Literal["deployment_id", "config", "service_instance_config"] | None: ...

global___DeploymentRef = DeploymentRef

class CompareDeploymentReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEW_DEPLOYMENT_FIELD_NUMBER: builtins.int
    PREV_DEPLOYMENT_FIELD_NUMBER: builtins.int
    @property
    def new_deployment(self) -> global___DeploymentRef: ...
    @property
    def prev_deployment(self) -> global___DeploymentRef: ...
    def __init__(
        self,
        *,
        new_deployment: global___DeploymentRef | None = ...,
        prev_deployment: global___DeploymentRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_deployment", b"new_deployment", "prev_deployment", b"prev_deployment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["new_deployment", b"new_deployment", "prev_deployment", b"prev_deployment"]) -> None: ...

global___CompareDeploymentReq = CompareDeploymentReq

class CompareDeploymentResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPARISON_FIELD_NUMBER: builtins.int
    @property
    def comparison(self) -> prodvana.proto.prodvana.deployment.object_pb2.DeploymentComparison: ...
    def __init__(
        self,
        *,
        comparison: prodvana.proto.prodvana.deployment.object_pb2.DeploymentComparison | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["comparison", b"comparison"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison", b"comparison"]) -> None: ...

global___CompareDeploymentResp = CompareDeploymentResp

class PreviewDeploymentReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    PREV_DEPLOYMENT_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.deployment.object_pb2.DeploymentConfig: ...
    @property
    def prev_deployment(self) -> global___DeploymentRef:
        """omit to use latest deployment from the same app/service/deployment channel"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.deployment.object_pb2.DeploymentConfig | None = ...,
        prev_deployment: global___DeploymentRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "prev_deployment", b"prev_deployment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "prev_deployment", b"prev_deployment"]) -> None: ...

global___PreviewDeploymentReq = PreviewDeploymentReq

class PreviewDeploymentResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_FIELD_NUMBER: builtins.int
    @property
    def deployment(self) -> prodvana.proto.prodvana.deployment.object_pb2.Deployment: ...
    def __init__(
        self,
        *,
        deployment: prodvana.proto.prodvana.deployment.object_pb2.Deployment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment", b"deployment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment", b"deployment"]) -> None: ...

global___PreviewDeploymentResp = PreviewDeploymentResp

class GetLatestDeploymentsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTERS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentFilter]:
        """filters for listing deployments. Multiple filters are OR'ed together."""
    @property
    def filter(self) -> global___DeploymentFilter:
        """escape hatch to support openAPI, which cannot handle repeated list of messages on GET requests. This is joined to the filters list with an OR."""
    status: prodvana.proto.prodvana.deployment.object_pb2.DeploymentStatus.ValueType
    """if set, only return deployments with this status"""
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        filters: collections.abc.Iterable[global___DeploymentFilter] | None = ...,
        filter: global___DeploymentFilter | None = ...,
        status: prodvana.proto.prodvana.deployment.object_pb2.DeploymentStatus.ValueType = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter", "filters", b"filters", "page_size", b"page_size", "page_token", b"page_token", "status", b"status"]) -> None: ...

global___GetLatestDeploymentsReq = GetLatestDeploymentsReq

class GetLatestDeploymentsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def deployments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.deployment.object_pb2.Deployment]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        deployments: collections.abc.Iterable[prodvana.proto.prodvana.deployment.object_pb2.Deployment] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployments", b"deployments", "next_page_token", b"next_page_token"]) -> None: ...

global___GetLatestDeploymentsResp = GetLatestDeploymentsResp

class DeploymentServiceInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "service", b"service"]) -> None: ...

global___DeploymentServiceInstance = DeploymentServiceInstance

class CheckCommitInDeploymentReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    DEPLOYMENT_SERVICE_INSTANCE_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    deployment_id: builtins.str
    @property
    def deployment_service_instance(self) -> global___DeploymentServiceInstance:
        """will pick latest deployment"""
    repository: builtins.str
    commit: builtins.str
    def __init__(
        self,
        *,
        deployment_id: builtins.str = ...,
        deployment_service_instance: global___DeploymentServiceInstance | None = ...,
        repository: builtins.str = ...,
        commit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deployment_id", b"deployment_id", "deployment_oneof", b"deployment_oneof", "deployment_service_instance", b"deployment_service_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit", b"commit", "deployment_id", b"deployment_id", "deployment_oneof", b"deployment_oneof", "deployment_service_instance", b"deployment_service_instance", "repository", b"repository"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["deployment_oneof", b"deployment_oneof"]) -> typing_extensions.Literal["deployment_id", "deployment_service_instance"] | None: ...

global___CheckCommitInDeploymentReq = CheckCommitInDeploymentReq

class CheckCommitInDeploymentResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Result:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CheckCommitInDeploymentResp._Result.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: CheckCommitInDeploymentResp._Result.ValueType  # 0
        INCLUDED: CheckCommitInDeploymentResp._Result.ValueType  # 1
        NO_RELATION: CheckCommitInDeploymentResp._Result.ValueType  # 2
        NOT_INCLUDED: CheckCommitInDeploymentResp._Result.ValueType  # 3

    class Result(_Result, metaclass=_ResultEnumTypeWrapper): ...
    UNKNOWN: CheckCommitInDeploymentResp.Result.ValueType  # 0
    INCLUDED: CheckCommitInDeploymentResp.Result.ValueType  # 1
    NO_RELATION: CheckCommitInDeploymentResp.Result.ValueType  # 2
    NOT_INCLUDED: CheckCommitInDeploymentResp.Result.ValueType  # 3

    RESULT_FIELD_NUMBER: builtins.int
    result: global___CheckCommitInDeploymentResp.Result.ValueType
    def __init__(
        self,
        *,
        result: global___CheckCommitInDeploymentResp.Result.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["result", b"result"]) -> None: ...

global___CheckCommitInDeploymentResp = CheckCommitInDeploymentResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.capability.capability_pb2
import prodvana.proto.prodvana.common_config.constants_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.helm_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.maturity_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.program_pb2
import prodvana.proto.prodvana.common_config.retry_pb2
import prodvana.proto.prodvana.common_config.rollback_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.delivery.delivery_config_pb2
import prodvana.proto.prodvana.delivery_extension.config_pb2
import prodvana.proto.prodvana.desired_state.maestro.maestro_pb2
import prodvana.proto.prodvana.protection.attachments_pb2
import prodvana.proto.prodvana.protection.protection_reference_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import prodvana.proto.prodvana.service.parameters_pb2
import prodvana.proto.prodvana.volumes.volumes_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ReplicasConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    fixed: builtins.int
    """no validations, server side has defaults"""
    def __init__(
        self,
        *,
        fixed: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "fixed", b"fixed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_oneof", b"config_oneof", "fixed", b"fixed"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["fixed"] | None: ...

global___ReplicasConfig = ReplicasConfig

class MetricAnalysis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class SuccessRateConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MIN_THRESHOLD_PERCENT_FIELD_NUMBER: builtins.int
        min_threshold_percent: builtins.float
        def __init__(
            self,
            *,
            min_threshold_percent: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["min_threshold_percent", b"min_threshold_percent"]) -> None: ...

    class LatencyConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MAX_LATENCY_FIELD_NUMBER: builtins.int
        @property
        def max_latency(self) -> google.protobuf.duration_pb2.Duration: ...
        def __init__(
            self,
            *,
            max_latency: google.protobuf.duration_pb2.Duration | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["max_latency", b"max_latency"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["max_latency", b"max_latency"]) -> None: ...

    SUCCESS_RATE_FIELD_NUMBER: builtins.int
    LATENCY_P95_FIELD_NUMBER: builtins.int
    @property
    def success_rate(self) -> global___MetricAnalysis.SuccessRateConfig: ...
    @property
    def latency_p95(self) -> global___MetricAnalysis.LatencyConfig: ...
    def __init__(
        self,
        *,
        success_rate: global___MetricAnalysis.SuccessRateConfig | None = ...,
        latency_p95: global___MetricAnalysis.LatencyConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["analysis_oneof", b"analysis_oneof", "latency_p95", b"latency_p95", "success_rate", b"success_rate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["analysis_oneof", b"analysis_oneof", "latency_p95", b"latency_p95", "success_rate", b"success_rate"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["analysis_oneof", b"analysis_oneof"]) -> typing_extensions.Literal["success_rate", "latency_p95"] | None: ...

global___MetricAnalysis = MetricAnalysis

class ReleaseStrategyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDIVIDUAL_STAGE_DEADLINE_FIELD_NUMBER: builtins.int
    AUTOMATED_TESTING_DURATION_FIELD_NUMBER: builtins.int
    METRICS_ANALYSIS_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    CHECK_INTERVAL_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    @property
    def individual_stage_deadline(self) -> google.protobuf.duration_pb2.Duration:
        """deadline in each stage before the push is rolled back. Includes the time it takes for pods to be healthy. Defaults to 10 minutes."""
    @property
    def automated_testing_duration(self) -> google.protobuf.duration_pb2.Duration:
        """duration of the automated testing phase, before manual approval. Defaults to 30m."""
    @property
    def metrics_analysis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricAnalysis]: ...
    manual_approval: builtins.bool
    @property
    def check_interval(self) -> google.protobuf.duration_pb2.Duration:
        """advanced settings that do not typically need to be set. Exposed mainly for testing purposes.
        defaults to 30s
        """
    failure_threshold: builtins.int
    """defaults to 5"""
    def __init__(
        self,
        *,
        individual_stage_deadline: google.protobuf.duration_pb2.Duration | None = ...,
        automated_testing_duration: google.protobuf.duration_pb2.Duration | None = ...,
        metrics_analysis: collections.abc.Iterable[global___MetricAnalysis] | None = ...,
        manual_approval: builtins.bool = ...,
        check_interval: google.protobuf.duration_pb2.Duration | None = ...,
        failure_threshold: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["automated_testing_duration", b"automated_testing_duration", "check_interval", b"check_interval", "individual_stage_deadline", b"individual_stage_deadline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automated_testing_duration", b"automated_testing_duration", "check_interval", b"check_interval", "failure_threshold", b"failure_threshold", "individual_stage_deadline", b"individual_stage_deadline", "manual_approval", b"manual_approval", "metrics_analysis", b"metrics_analysis"]) -> None: ...

global___ReleaseStrategyConfig = ReleaseStrategyConfig

class TLSSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_SECRET_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    raw_secret: builtins.str
    """Raw secret value to be used for user-editable YAML and RPC calls."""
    @property
    def secret(self) -> prodvana.proto.prodvana.common_config.env_pb2.Secret:
        """Externally stored secret."""
    def __init__(
        self,
        *,
        raw_secret: builtins.str = ...,
        secret: prodvana.proto.prodvana.common_config.env_pb2.Secret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["raw_secret", b"raw_secret", "secret", b"secret", "tls_secret", b"tls_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_secret", b"raw_secret", "secret", b"secret", "tls_secret", b"tls_secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["tls_secret", b"tls_secret"]) -> typing_extensions.Literal["raw_secret", "secret"] | None: ...

global___TLSSecret = TLSSecret

class TLSCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TLS_CERT_FIELD_NUMBER: builtins.int
    TLS_KEY_FIELD_NUMBER: builtins.int
    @property
    def tls_cert(self) -> global___TLSSecret: ...
    @property
    def tls_key(self) -> global___TLSSecret: ...
    def __init__(
        self,
        *,
        tls_cert: global___TLSSecret | None = ...,
        tls_key: global___TLSSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tls_cert", b"tls_cert", "tls_key", b"tls_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tls_cert", b"tls_cert", "tls_key", b"tls_key"]) -> None: ...

global___TLSCertificate = TLSCertificate

class Certificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TLS_FIELD_NUMBER: builtins.int
    AWS_ACM_CERT_FIELD_NUMBER: builtins.int
    @property
    def tls(self) -> global___TLSCertificate: ...
    aws_acm_cert: builtins.str
    def __init__(
        self,
        *,
        tls: global___TLSCertificate | None = ...,
        aws_acm_cert: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_acm_cert", b"aws_acm_cert", "certificate", b"certificate", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_acm_cert", b"aws_acm_cert", "certificate", b"certificate", "tls", b"tls"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["certificate", b"certificate"]) -> typing_extensions.Literal["tls", "aws_acm_cert"] | None: ...

global___Certificate = Certificate

class PerReleaseChannelConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    CUSTOM_HOSTNAMES_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    CERT_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSIONS_FIELD_NUMBER: builtins.int
    RUNTIME_SPECIFIC_FIELD_NUMBER: builtins.int
    RUNTIME_CONNECTION_FIELD_NUMBER: builtins.int
    RUNTIME_EXTENSION_FIELD_NUMBER: builtins.int
    CUSTOM_RUNTIME_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    EXTERNAL_CONFIG_FIELD_NUMBER: builtins.int
    HELM_FIELD_NUMBER: builtins.int
    AWS_ECS_FIELD_NUMBER: builtins.int
    GOOGLE_CLOUD_RUN_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    PROTECTIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    @property
    def custom_hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.PerReleaseChannelProgramConfig]: ...
    @property
    def cert(self) -> global___Certificate: ...
    @property
    def delivery_config(self) -> prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]: ...
    @property
    def replicas(self) -> global___ReplicasConfig: ...
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskConfig]:
        """DEPRECATED: use convergence_extensions"""
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]:
        """DEPRECATED: use convergence_extensions"""
    @property
    def convergence_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]: ...
    @property
    def runtime_specific(self) -> global___RuntimeSpecificConfig: ...
    runtime_connection: builtins.str
    """which runtime connection to use in each release channel.
    optional if only one runtime makes sense for the service config.
    """
    @property
    def runtime_extension(self) -> global___RuntimeExtensionConfig:
        """deprecated, use custom_runtime"""
    @property
    def custom_runtime(self) -> global___RuntimeExtensionConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def external_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig:
        """deprecated, pass this as kubernetes_config instead"""
    @property
    def helm(self) -> prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig: ...
    @property
    def aws_ecs(self) -> global___AwsEcsConfig: ...
    @property
    def google_cloud_run(self) -> global___GoogleCloudRunConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """Additional env variables that are injected to the service.
        This can be useful for injecting and/or overriding env variables from release channel
        configs for Kubernetes and runtime extension configs.
        Not supported for helm configs.
        """
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    @property
    def convergence_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]:
        """TODO: unused today, but will be used for per-service per-RC convergence protections in the future"""
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
        custom_hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.PerReleaseChannelProgramConfig] | None = ...,
        cert: global___Certificate | None = ...,
        delivery_config: prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        replicas: global___ReplicasConfig | None = ...,
        pre_push_tasks: collections.abc.Iterable[global___TaskConfig] | None = ...,
        delivery_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        convergence_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        runtime_specific: global___RuntimeSpecificConfig | None = ...,
        runtime_connection: builtins.str = ...,
        runtime_extension: global___RuntimeExtensionConfig | None = ...,
        custom_runtime: global___RuntimeExtensionConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        external_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        helm: prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig | None = ...,
        aws_ecs: global___AwsEcsConfig | None = ...,
        google_cloud_run: global___GoogleCloudRunConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        convergence_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_ecs", b"aws_ecs", "cert", b"cert", "config_oneof", b"config_oneof", "custom_runtime", b"custom_runtime", "delivery_config", b"delivery_config", "external_config", b"external_config", "google_cloud_run", b"google_cloud_run", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "replicas", b"replicas", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_ecs", b"aws_ecs", "cert", b"cert", "config_oneof", b"config_oneof", "constants", b"constants", "convergence_extensions", b"convergence_extensions", "convergence_protections", b"convergence_protections", "custom_hostnames", b"custom_hostnames", "custom_runtime", b"custom_runtime", "delivery_config", b"delivery_config", "delivery_extensions", b"delivery_extensions", "env", b"env", "external_config", b"external_config", "google_cloud_run", b"google_cloud_run", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "pre_push_tasks", b"pre_push_tasks", "programs", b"programs", "protections", b"protections", "release_channel", b"release_channel", "replicas", b"replicas", "runtime_connection", b"runtime_connection", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific", "volumes", b"volumes"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["runtime_extension", "custom_runtime", "kubernetes_config", "external_config", "helm", "aws_ecs", "google_cloud_run"] | None: ...

global___PerReleaseChannelConfig = PerReleaseChannelConfig

class CapabilityReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___CapabilityReference = CapabilityReference

class CompiledCapabilityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPABILITY_FIELD_NUMBER: builtins.int
    @property
    def capability(self) -> prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig: ...
    def __init__(
        self,
        *,
        capability: prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capability", b"capability"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capability", b"capability"]) -> None: ...

global___CompiledCapabilityConfig = CompiledCapabilityConfig

class ProgramReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["name", b"name", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "ref", b"ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["ref", b"ref"]) -> typing_extensions.Literal["name"] | None: ...

global___ProgramReference = ProgramReference

class TaskReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ref", b"ref", "release_channel", b"release_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ref", b"ref", "release_channel", b"release_channel"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["ref", b"ref"]) -> typing_extensions.Literal["release_channel"] | None: ...

global___TaskReference = TaskReference

class TaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRAM_FIELD_NUMBER: builtins.int
    BASE_PROGRAM_FIELD_NUMBER: builtins.int
    RETRY_CONFIG_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    @property
    def program(self) -> prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig: ...
    @property
    def base_program(self) -> global___ProgramReference:
        """optional base program to take configs from. If specified, `program` field will act
        like an override instead.
        """
    @property
    def retry_config(self) -> prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig:
        """if not set, the task will not be retried once it starts executing once."""
    @property
    def ref(self) -> global___TaskReference:
        """Instead of defining a new task, reference an existing custom task and use that. This is meant
        to be used in conjunection with per_release_channel to allow multiple release channels to use
        a single custom task. If set, the program definition is ignored except for program name.
        """
    def __init__(
        self,
        *,
        program: prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig | None = ...,
        base_program: global___ProgramReference | None = ...,
        retry_config: prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig | None = ...,
        ref: global___TaskReference | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_program", b"base_program", "program", b"program", "ref", b"ref", "retry_config", b"retry_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_program", b"base_program", "program", b"program", "ref", b"ref", "retry_config", b"retry_config"]) -> None: ...

global___TaskConfig = TaskConfig

class ProtectionLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIFECYCLE_FIELD_NUMBER: builtins.int
    ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def lifecycle(self) -> prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle: ...
    attachment_id: builtins.str
    def __init__(
        self,
        *,
        lifecycle: prodvana.proto.prodvana.protection.protection_reference_pb2.ProtectionLifecycle | None = ...,
        attachment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lifecycle", b"lifecycle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment_id", b"attachment_id", "lifecycle", b"lifecycle"]) -> None: ...

global___ProtectionLink = ProtectionLink

class DeliveryExtensionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    @property
    def inlined(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig:
        """Inline definition of a delivery extension."""
    instance: builtins.str
    """A delivery instance defined in this service config."""
    @property
    def ref(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef:
        """Reference to a delivery extension defined externally."""
    lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType
    def __init__(
        self,
        *,
        inlined: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        instance: builtins.str = ...,
        ref: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef | None = ...,
        lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "instance", b"instance", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "instance", b"instance", "lifecycle", b"lifecycle", "ref", b"ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["definition", b"definition"]) -> typing_extensions.Literal["inlined", "instance", "ref"] | None: ...

global___DeliveryExtensionConfig = DeliveryExtensionConfig

class DeliveryExtensionInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    REF_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def inlined(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig:
        """Inline definition of the delivery extension."""
    @property
    def ref(self) -> prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef:
        """Reference to a delivery extension defined externally."""
    name: builtins.str
    def __init__(
        self,
        *,
        inlined: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionConfig | None = ...,
        ref: prodvana.proto.prodvana.delivery_extension.config_pb2.DeliveryExtensionInstanceRef | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "ref", b"ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["definition", b"definition", "inlined", b"inlined", "name", b"name", "ref", b"ref"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["definition", b"definition"]) -> typing_extensions.Literal["inlined", "ref"] | None: ...

global___DeliveryExtensionInstance = DeliveryExtensionInstance

class RuntimeSpecificConfig(google.protobuf.message.Message):
    """RuntimeSpecificConfig contains Service level configuration options that only make sense for a
    specific Runtime type. Configuration added here should only apply to a single Service; if the
    Runtime specific configuration relates to all services, it should be configured as at the
    Runtime cluster level (or as a runtime extension).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class K8SConfig(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class ServiceAnnotationsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        SERVICE_ANNOTATIONS_FIELD_NUMBER: builtins.int
        @property
        def service_annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
            """Annotations to add to the Kubernetes Service object"""
        def __init__(
            self,
            *,
            service_annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["service_annotations", b"service_annotations"]) -> None: ...

    K8S_FIELD_NUMBER: builtins.int
    @property
    def k8s(self) -> global___RuntimeSpecificConfig.K8SConfig: ...
    def __init__(
        self,
        *,
        k8s: global___RuntimeSpecificConfig.K8SConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["k8s", b"k8s", "runtime_config", b"runtime_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["k8s", b"k8s", "runtime_config", b"runtime_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["runtime_config", b"runtime_config"]) -> typing_extensions.Literal["k8s"] | None: ...

global___RuntimeSpecificConfig = RuntimeSpecificConfig

class RuntimeExtensionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    CLEAR_ON_PER_RELEASE_CHANNEL_MERGE_FIELD_NUMBER: builtins.int
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    clear_on_per_release_channel_merge: builtins.bool
    """can only be set on a PerReleaseChannel config. If set, parameter values will be replaced instead of joined."""
    def __init__(
        self,
        *,
        parameter_values: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        clear_on_per_release_channel_merge: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["clear_on_per_release_channel_merge", b"clear_on_per_release_channel_merge", "parameter_values", b"parameter_values"]) -> None: ...

global___RuntimeExtensionConfig = RuntimeExtensionConfig

class AwsEcsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Spec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INLINED_FIELD_NUMBER: builtins.int
        LOCAL_FIELD_NUMBER: builtins.int
        REMOTE_FIELD_NUMBER: builtins.int
        inlined: builtins.str
        @property
        def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
        @property
        def remote(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig: ...
        def __init__(
            self,
            *,
            inlined: builtins.str = ...,
            local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
            remote: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "spec_oneof", b"spec_oneof"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "spec_oneof", b"spec_oneof"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["spec_oneof", b"spec_oneof"]) -> typing_extensions.Literal["inlined", "local", "remote"] | None: ...

    ECS_SERVICE_NAME_OVERRIDE_FIELD_NUMBER: builtins.int
    TASK_DEFINITION_FIELD_NUMBER: builtins.int
    SERVICE_DEFINITION_FIELD_NUMBER: builtins.int
    UPDATE_TASK_DEFINITION_ONLY_FIELD_NUMBER: builtins.int
    ecs_service_name_override: builtins.str
    """optional, defaults to Prodvana service name"""
    @property
    def task_definition(self) -> global___AwsEcsConfig.Spec: ...
    @property
    def service_definition(self) -> global___AwsEcsConfig.Spec: ...
    update_task_definition_only: builtins.bool
    """Only update service's task definition, but do not try to update anything else about the service.
    This means that something else is responsible for creating the service.
    if set, network_configuration cannot be set
    """
    def __init__(
        self,
        *,
        ecs_service_name_override: builtins.str = ...,
        task_definition: global___AwsEcsConfig.Spec | None = ...,
        service_definition: global___AwsEcsConfig.Spec | None = ...,
        update_task_definition_only: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["service_definition", b"service_definition", "task_definition", b"task_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ecs_service_name_override", b"ecs_service_name_override", "service_definition", b"service_definition", "task_definition", b"task_definition", "update_task_definition_only", b"update_task_definition_only"]) -> None: ...

global___AwsEcsConfig = AwsEcsConfig

class GoogleCloudRunConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    inlined: builtins.str
    @property
    def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
    @property
    def remote(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig: ...
    def __init__(
        self,
        *,
        inlined: builtins.str = ...,
        local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
        remote: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "spec_oneof", b"spec_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "spec_oneof", b"spec_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["spec_oneof", b"spec_oneof"]) -> typing_extensions.Literal["inlined", "local", "remote"] | None: ...

global___GoogleCloudRunConfig = GoogleCloudRunConfig

class ServiceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ParametersAutogen:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ParametersAutogenEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ServiceConfig._ParametersAutogen.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ServiceConfig._ParametersAutogen.ValueType  # 0
        NONE: ServiceConfig._ParametersAutogen.ValueType  # 1
        """no autogen"""
        IMAGE: ServiceConfig._ParametersAutogen.ValueType  # 2
        """autogen one parameter per program for the image"""
        IMAGE_AND_REPLICAS: ServiceConfig._ParametersAutogen.ValueType  # 3
        """IMAGE + autogen a parameter for replicas count"""

    class ParametersAutogen(_ParametersAutogen, metaclass=_ParametersAutogenEnumTypeWrapper): ...
    UNKNOWN: ServiceConfig.ParametersAutogen.ValueType  # 0
    NONE: ServiceConfig.ParametersAutogen.ValueType  # 1
    """no autogen"""
    IMAGE: ServiceConfig.ParametersAutogen.ValueType  # 2
    """autogen one parameter per program for the image"""
    IMAGE_AND_REPLICAS: ServiceConfig.ParametersAutogen.ValueType  # 3
    """IMAGE + autogen a parameter for replicas count"""

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    RELEASE_STRATEGY_FIELD_NUMBER: builtins.int
    PER_RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    DEPLOY_ANNOTATIONS_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSIONS_FIELD_NUMBER: builtins.int
    DELIVERY_EXTENSION_INSTANCES_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSION_INSTANCES_FIELD_NUMBER: builtins.int
    CONVERGENCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    RUNTIME_SPECIFIC_FIELD_NUMBER: builtins.int
    RUNTIME_CONNECTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    PROGRESS_DEADLINE_FIELD_NUMBER: builtins.int
    RUNTIME_EXTENSION_FIELD_NUMBER: builtins.int
    CUSTOM_RUNTIME_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    EXTERNAL_CONFIG_FIELD_NUMBER: builtins.int
    HELM_FIELD_NUMBER: builtins.int
    AWS_ECS_FIELD_NUMBER: builtins.int
    GOOGLE_CLOUD_RUN_FIELD_NUMBER: builtins.int
    PARAMETERS_AUTOGEN_FIELD_NUMBER: builtins.int
    AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    NO_CLEANUP_ON_DELETE_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ASYNC_SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    MAESTRO_FIELD_NUMBER: builtins.int
    BUNDLE_NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    application: builtins.str
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig]: ...
    @property
    def replicas(self) -> global___ReplicasConfig: ...
    @property
    def release_strategy(self) -> global___ReleaseStrategyConfig: ...
    @property
    def per_release_channel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PerReleaseChannelConfig]: ...
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CapabilityReference]:
        """deprecated"""
    @property
    def delivery_config(self) -> prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]: ...
    @property
    def deploy_annotations(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig: ...
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskConfig]:
        """DEPRECATED: Replace with convergence_extensions"""
    @property
    def delivery_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]:
        """DEPRECATED: use convergence_extensions"""
    @property
    def delivery_extension_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionInstance]: ...
    @property
    def convergence_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]: ...
    @property
    def convergence_extension_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionInstance]: ...
    @property
    def convergence_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]:
        """Convergence protections applied to all release channels."""
    @property
    def runtime_specific(self) -> global___RuntimeSpecificConfig: ...
    runtime_connection: builtins.str
    """which runtime connection to use in each release channel.
    optional if only one runtime makes sense for the service config.
    """
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def parameter_values(self) -> prodvana.proto.prodvana.service.parameters_pb2.ServiceParameterValues:
        """only valid to set in compiled configs by Prodvana"""
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def progress_deadline(self) -> google.protobuf.duration_pb2.Duration:
        """how long to wait before marking deployment as failed"""
    @property
    def runtime_extension(self) -> global___RuntimeExtensionConfig:
        """deprecated, use custom_runtime below"""
    @property
    def custom_runtime(self) -> global___RuntimeExtensionConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def external_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig:
        """deprecated, pass this as kubernetes_config instead"""
    @property
    def helm(self) -> prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig: ...
    @property
    def aws_ecs(self) -> global___AwsEcsConfig: ...
    @property
    def google_cloud_run(self) -> global___GoogleCloudRunConfig: ...
    parameters_autogen: global___ServiceConfig.ParametersAutogen.ValueType
    """How to autogenerate parameters, defaults to IMAGE. Ignored for Kubernetes or Helm configs."""
    @property
    def auto_rollback(self) -> prodvana.proto.prodvana.common_config.rollback_pb2.AutoRollbackConfig: ...
    no_cleanup_on_delete: builtins.bool
    """if set, do not attempt to delete the underlying runtime objects when deleting a service"""
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """Additional env variables that are injected to the service.
        This can be useful for injecting and/or overriding env variables from release channel
        configs for Kubernetes and runtime extension configs.
        Not supported for helm configs.
        """
    async_set_desired_state: builtins.bool
    """internal use"""
    @property
    def maestro(self) -> prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroConfig: ...
    bundle_name: builtins.str
    """optional, customize the name of the bundle that will be created for this service.
    By default, the bundle name is generated based on input parameters, such as commit hash.
    The bundle name cannot be different per Release Channel. Doing so is an error.
    If the generated bundle name already exists, a number will be appended to resolve conflict.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        application: builtins.str = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig] | None = ...,
        replicas: global___ReplicasConfig | None = ...,
        release_strategy: global___ReleaseStrategyConfig | None = ...,
        per_release_channel: collections.abc.Iterable[global___PerReleaseChannelConfig] | None = ...,
        capabilities: collections.abc.Iterable[global___CapabilityReference] | None = ...,
        delivery_config: prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        deploy_annotations: prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig | None = ...,
        pre_push_tasks: collections.abc.Iterable[global___TaskConfig] | None = ...,
        delivery_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        delivery_extension_instances: collections.abc.Iterable[global___DeliveryExtensionInstance] | None = ...,
        convergence_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        convergence_extension_instances: collections.abc.Iterable[global___DeliveryExtensionInstance] | None = ...,
        convergence_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        runtime_specific: global___RuntimeSpecificConfig | None = ...,
        runtime_connection: builtins.str = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        parameter_values: prodvana.proto.prodvana.service.parameters_pb2.ServiceParameterValues | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        progress_deadline: google.protobuf.duration_pb2.Duration | None = ...,
        runtime_extension: global___RuntimeExtensionConfig | None = ...,
        custom_runtime: global___RuntimeExtensionConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        external_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        helm: prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig | None = ...,
        aws_ecs: global___AwsEcsConfig | None = ...,
        google_cloud_run: global___GoogleCloudRunConfig | None = ...,
        parameters_autogen: global___ServiceConfig.ParametersAutogen.ValueType = ...,
        auto_rollback: prodvana.proto.prodvana.common_config.rollback_pb2.AutoRollbackConfig | None = ...,
        no_cleanup_on_delete: builtins.bool = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        async_set_desired_state: builtins.bool = ...,
        maestro: prodvana.proto.prodvana.desired_state.maestro.maestro_pb2.MaestroConfig | None = ...,
        bundle_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_rollback", b"auto_rollback", "aws_ecs", b"aws_ecs", "config_oneof", b"config_oneof", "custom_runtime", b"custom_runtime", "delivery_config", b"delivery_config", "deploy_annotations", b"deploy_annotations", "external_config", b"external_config", "google_cloud_run", b"google_cloud_run", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "maestro", b"maestro", "parameter_values", b"parameter_values", "progress_deadline", b"progress_deadline", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "async_set_desired_state", b"async_set_desired_state", "auto_rollback", b"auto_rollback", "aws_ecs", b"aws_ecs", "bundle_name", b"bundle_name", "capabilities", b"capabilities", "config_oneof", b"config_oneof", "constants", b"constants", "convergence_extension_instances", b"convergence_extension_instances", "convergence_extensions", b"convergence_extensions", "convergence_protections", b"convergence_protections", "custom_runtime", b"custom_runtime", "delivery_config", b"delivery_config", "delivery_extension_instances", b"delivery_extension_instances", "delivery_extensions", b"delivery_extensions", "deploy_annotations", b"deploy_annotations", "env", b"env", "external_config", b"external_config", "google_cloud_run", b"google_cloud_run", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "maestro", b"maestro", "name", b"name", "no_cleanup_on_delete", b"no_cleanup_on_delete", "parameter_values", b"parameter_values", "parameters", b"parameters", "parameters_autogen", b"parameters_autogen", "per_release_channel", b"per_release_channel", "pre_push_tasks", b"pre_push_tasks", "programs", b"programs", "progress_deadline", b"progress_deadline", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime_connection", b"runtime_connection", "runtime_extension", b"runtime_extension", "runtime_specific", b"runtime_specific", "volumes", b"volumes"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["runtime_extension", "custom_runtime", "kubernetes_config", "external_config", "helm", "aws_ecs", "google_cloud_run"] | None: ...

global___ServiceConfig = ServiceConfig

class CompiledServiceInstanceConfig(google.protobuf.message.Message):
    """a compiled version of ServiceConfig specific to a service instance, with release-channel configs applied"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    SERVICE_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    MATURITY_FIELD_NUMBER: builtins.int
    RELEASE_STRATEGY_FIELD_NUMBER: builtins.int
    CUSTOM_HOSTNAMES_FIELD_NUMBER: builtins.int
    CERT_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    DELIVERY_CONFIG_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    DEPLOY_ANNOTATIONS_FIELD_NUMBER: builtins.int
    PRE_PUSH_TASKS_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSION_INSTANCES_FIELD_NUMBER: builtins.int
    RUNTIME_SPECIFIC_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PARAMETER_VALUES_FIELD_NUMBER: builtins.int
    CONSTANTS_FIELD_NUMBER: builtins.int
    PROGRESS_DEADLINE_FIELD_NUMBER: builtins.int
    CUSTOM_RUNTIME_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    HELM_FIELD_NUMBER: builtins.int
    AWS_ECS_FIELD_NUMBER: builtins.int
    GOOGLE_CLOUD_RUN_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    NO_CLEANUP_ON_DELETE_FIELD_NUMBER: builtins.int
    PROTECTIONS_FIELD_NUMBER: builtins.int
    CONVERGENCE_PROTECTIONS_FIELD_NUMBER: builtins.int
    BUNDLE_NAME_FIELD_NUMBER: builtins.int
    service: builtins.str
    application: builtins.str
    release_channel: builtins.str
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig]: ...
    @property
    def replicas(self) -> global___ReplicasConfig: ...
    maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType
    @property
    def release_strategy(self) -> global___ReleaseStrategyConfig: ...
    @property
    def custom_hostnames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def cert(self) -> global___Certificate: ...
    @property
    def runtime(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig: ...
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CompiledCapabilityConfig]: ...
    @property
    def delivery_config(self) -> prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]: ...
    @property
    def deploy_annotations(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig: ...
    @property
    def pre_push_tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskConfig]:
        """DEPRECATED: use convergence_extensions"""
    @property
    def convergence_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionConfig]: ...
    @property
    def convergence_extension_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeliveryExtensionInstance]: ...
    @property
    def runtime_specific(self) -> global___RuntimeSpecificConfig: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def parameter_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue]: ...
    @property
    def constants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.constants_pb2.Constant]:
        """constants made available in template substitutions"""
    @property
    def progress_deadline(self) -> google.protobuf.duration_pb2.Duration:
        """how long to wait before marking deployment as failed"""
    @property
    def custom_runtime(self) -> global___RuntimeExtensionConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def helm(self) -> prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig: ...
    @property
    def aws_ecs(self) -> global___AwsEcsConfig: ...
    @property
    def google_cloud_run(self) -> global___GoogleCloudRunConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """The compiled environment for this instance's context, e.g.  Release Channel.
        This is used to inject these values into external configs.
        """
    no_cleanup_on_delete: builtins.bool
    @property
    def protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    @property
    def convergence_protections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig]: ...
    bundle_name: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig] | None = ...,
        replicas: global___ReplicasConfig | None = ...,
        maturity: prodvana.proto.prodvana.common_config.maturity_pb2.Maturity.ValueType = ...,
        release_strategy: global___ReleaseStrategyConfig | None = ...,
        custom_hostnames: collections.abc.Iterable[builtins.str] | None = ...,
        cert: global___Certificate | None = ...,
        runtime: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        capabilities: collections.abc.Iterable[global___CompiledCapabilityConfig] | None = ...,
        delivery_config: prodvana.proto.prodvana.delivery.delivery_config_pb2.DeliveryConfig | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        deploy_annotations: prodvana.proto.prodvana.workflow.integration_config_pb2.AnnotationsConfig | None = ...,
        pre_push_tasks: collections.abc.Iterable[global___TaskConfig] | None = ...,
        convergence_extensions: collections.abc.Iterable[global___DeliveryExtensionConfig] | None = ...,
        convergence_extension_instances: collections.abc.Iterable[global___DeliveryExtensionInstance] | None = ...,
        runtime_specific: global___RuntimeSpecificConfig | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        parameter_values: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterValue] | None = ...,
        constants: collections.abc.Iterable[prodvana.proto.prodvana.common_config.constants_pb2.Constant] | None = ...,
        progress_deadline: google.protobuf.duration_pb2.Duration | None = ...,
        custom_runtime: global___RuntimeExtensionConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        helm: prodvana.proto.prodvana.common_config.helm_pb2.HelmConfig | None = ...,
        aws_ecs: global___AwsEcsConfig | None = ...,
        google_cloud_run: global___GoogleCloudRunConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        no_cleanup_on_delete: builtins.bool = ...,
        protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        convergence_protections: collections.abc.Iterable[prodvana.proto.prodvana.protection.attachments_pb2.ProtectionAttachmentConfig] | None = ...,
        bundle_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_ecs", b"aws_ecs", "cert", b"cert", "config_oneof", b"config_oneof", "custom_runtime", b"custom_runtime", "delivery_config", b"delivery_config", "deploy_annotations", b"deploy_annotations", "google_cloud_run", b"google_cloud_run", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "progress_deadline", b"progress_deadline", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime", b"runtime", "runtime_execution", b"runtime_execution", "runtime_specific", b"runtime_specific"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "aws_ecs", b"aws_ecs", "bundle_name", b"bundle_name", "capabilities", b"capabilities", "cert", b"cert", "config_oneof", b"config_oneof", "constants", b"constants", "convergence_extension_instances", b"convergence_extension_instances", "convergence_extensions", b"convergence_extensions", "convergence_protections", b"convergence_protections", "custom_hostnames", b"custom_hostnames", "custom_runtime", b"custom_runtime", "delivery_config", b"delivery_config", "deploy_annotations", b"deploy_annotations", "env", b"env", "google_cloud_run", b"google_cloud_run", "helm", b"helm", "kubernetes_config", b"kubernetes_config", "maturity", b"maturity", "no_cleanup_on_delete", b"no_cleanup_on_delete", "parameter_values", b"parameter_values", "parameters", b"parameters", "pre_push_tasks", b"pre_push_tasks", "programs", b"programs", "progress_deadline", b"progress_deadline", "protections", b"protections", "release_channel", b"release_channel", "release_strategy", b"release_strategy", "replicas", b"replicas", "runtime", b"runtime", "runtime_execution", b"runtime_execution", "runtime_specific", b"runtime_specific", "service", b"service", "volumes", b"volumes"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["config_oneof", b"config_oneof"]) -> typing_extensions.Literal["custom_runtime", "kubernetes_config", "helm", "aws_ecs", "google_cloud_run"] | None: ...

global___CompiledServiceInstanceConfig = CompiledServiceInstanceConfig

class CompiledJobConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_PREFIX_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PROGRAMS_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    name_prefix: builtins.str
    release_channel: builtins.str
    @property
    def programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig]: ...
    @property
    def runtime(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig: ...
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    def __init__(
        self,
        *,
        name_prefix: builtins.str = ...,
        release_channel: builtins.str = ...,
        programs: collections.abc.Iterable[prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig] | None = ...,
        runtime: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelRuntimeConfig | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime", b"runtime", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name_prefix", b"name_prefix", "programs", b"programs", "release_channel", b"release_channel", "runtime", b"runtime", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledJobConfig = CompiledJobConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.delivery_extension.manager_pb2

class DeliveryExtensionManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureDeliveryExtension: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_extension.manager_pb2.ConfigureDeliveryExtensionReq,
        prodvana.proto.prodvana.delivery_extension.manager_pb2.ConfigureDeliveryExtensionResp,
    ]
    ValidateConfigureDeliveryExtension: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_extension.manager_pb2.ConfigureDeliveryExtensionReq,
        prodvana.proto.prodvana.delivery_extension.manager_pb2.ValidateConfigureDeliveryExtensionResp,
    ]
    ListDeliveryExtensions: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_extension.manager_pb2.ListDeliveryExtensionsReq,
        prodvana.proto.prodvana.delivery_extension.manager_pb2.ListDeliveryExtensionsResp,
    ]
    GetDeliveryExtension: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionReq,
        prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionResp,
    ]
    GetDeliveryExtensionConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionConfigReq,
        prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionConfigResp,
    ]
    GetDeliveryExtensionInstanceConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionInstanceConfigReq,
        prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionInstanceConfigResp,
    ]

class DeliveryExtensionManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureDeliveryExtension(
        self,
        request: prodvana.proto.prodvana.delivery_extension.manager_pb2.ConfigureDeliveryExtensionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_extension.manager_pb2.ConfigureDeliveryExtensionResp: ...
    @abc.abstractmethod
    def ValidateConfigureDeliveryExtension(
        self,
        request: prodvana.proto.prodvana.delivery_extension.manager_pb2.ConfigureDeliveryExtensionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_extension.manager_pb2.ValidateConfigureDeliveryExtensionResp: ...
    @abc.abstractmethod
    def ListDeliveryExtensions(
        self,
        request: prodvana.proto.prodvana.delivery_extension.manager_pb2.ListDeliveryExtensionsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_extension.manager_pb2.ListDeliveryExtensionsResp: ...
    @abc.abstractmethod
    def GetDeliveryExtension(
        self,
        request: prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionResp: ...
    @abc.abstractmethod
    def GetDeliveryExtensionConfig(
        self,
        request: prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionConfigResp: ...
    @abc.abstractmethod
    def GetDeliveryExtensionInstanceConfig(
        self,
        request: prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionInstanceConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_extension.manager_pb2.GetDeliveryExtensionInstanceConfigResp: ...

def add_DeliveryExtensionManagerServicer_to_server(servicer: DeliveryExtensionManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.links_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OrganizationUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_LINKS_FIELD_NUMBER: builtins.int
    SERVICE_LINKS_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    @property
    def application_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]:
        """Links that every app should get automatically"""
    @property
    def service_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]:
        """Links that every service should get automatically"""
    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]: ...
    def __init__(
        self,
        *,
        application_links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
        service_links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
        links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_links", b"application_links", "links", b"links", "service_links", b"service_links"]) -> None: ...

global___OrganizationUserMetadata = OrganizationUserMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import prodvana.proto.prodvana.blobs.blobs_manager_pb2

class BlobsManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetCasBlob: grpc.UnaryStreamMultiCallable[
        prodvana.proto.prodvana.blobs.blobs_manager_pb2.GetCasBlobReq,
        prodvana.proto.prodvana.blobs.blobs_manager_pb2.GetCasBlobResp,
    ]
    UploadCasBlob: grpc.StreamUnaryMultiCallable[
        prodvana.proto.prodvana.blobs.blobs_manager_pb2.UploadCasBlobReq,
        prodvana.proto.prodvana.blobs.blobs_manager_pb2.UploadCasBlobResp,
    ]

class BlobsManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCasBlob(
        self,
        request: prodvana.proto.prodvana.blobs.blobs_manager_pb2.GetCasBlobReq,
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[prodvana.proto.prodvana.blobs.blobs_manager_pb2.GetCasBlobResp]: ...
    @abc.abstractmethod
    def UploadCasBlob(
        self,
        request_iterator: collections.abc.Iterator[prodvana.proto.prodvana.blobs.blobs_manager_pb2.UploadCasBlobReq],
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.blobs.blobs_manager_pb2.UploadCasBlobResp: ...

def add_BlobsManagerServicer_to_server(servicer: BlobsManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.events.events_pb2
import prodvana.proto.prodvana.release_channel.object_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureReleaseChannelReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    FORCE_CREATE_NEW_VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    @property
    def release_channel(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    force_create_new_version: builtins.bool
    """create new version even if there are no detected changes"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        force_create_new_version: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "force_create_new_version", b"force_create_new_version", "release_channel", b"release_channel", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureReleaseChannelReq = ConfigureReleaseChannelReq

class ConfigureReleaseChannelResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    CREATED_NEW_VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """application version"""
    created_new_version: builtins.bool
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        created_new_version: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_new_version", b"created_new_version", "version", b"version"]) -> None: ...

global___ConfigureReleaseChannelResp = ConfigureReleaseChannelResp

class DeleteReleaseChannelReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    application: builtins.str
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
        application: builtins.str = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___DeleteReleaseChannelReq = DeleteReleaseChannelReq

class DeleteReleaseChannelResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """application version"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___DeleteReleaseChannelResp = DeleteReleaseChannelResp

class ListReleaseChannelsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___ListReleaseChannelsReq = ListReleaseChannelsReq

class ListReleaseChannelsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel]: ...
    def __init__(
        self,
        *,
        release_channels: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_channels", b"release_channels"]) -> None: ...

global___ListReleaseChannelsResp = ListReleaseChannelsResp

class GetReleaseChannelReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel"]) -> None: ...

global___GetReleaseChannelReq = GetReleaseChannelReq

class GetReleaseChannelResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    @property
    def release_channel(self) -> prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel: ...
    def __init__(
        self,
        *,
        release_channel: prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel"]) -> None: ...

global___GetReleaseChannelResp = GetReleaseChannelResp

class GetReleaseChannelConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "version", b"version"]) -> None: ...

global___GetReleaseChannelConfigReq = GetReleaseChannelConfigReq

class GetReleaseChannelConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig:
        """config as passed in by user"""
    version: builtins.str
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig:
        """config with defaults applied"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
        version: builtins.str = ...,
        compiled_config: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "version", b"version"]) -> None: ...

global___GetReleaseChannelConfigResp = GetReleaseChannelConfigResp

class GetReleaseChannelEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    ORDER_BY_DESC_TIMESTAMP_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    order_by_desc_timestamp: builtins.bool
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
        order_by_desc_timestamp: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "order_by_desc_timestamp", b"order_by_desc_timestamp", "page_size", b"page_size", "page_token", b"page_token", "release_channel", b"release_channel"]) -> None: ...

global___GetReleaseChannelEventsReq = GetReleaseChannelEventsReq

class GetReleaseChannelEventsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.events.events_pb2.Event]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[prodvana.proto.prodvana.events.events_pb2.Event] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "next_page_token", b"next_page_token"]) -> None: ...

global___GetReleaseChannelEventsResp = GetReleaseChannelEventsResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/release_channel_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.events import events_pb2 as prodvana_dot_events_dot_events__pb2
from prodvana.proto.prodvana.release_channel import object_pb2 as prodvana_dot_release__channel_dot_object__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6prodvana/release_channel/release_channel_manager.proto\x12\x18prodvana.release_channel\x1a\x1cgoogle/api/annotations.proto\x1a\x1cprodvana/events/events.proto\x1a%prodvana/release_channel/object.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xb0\x02\n\x1a\x43onfigureReleaseChannelReq\x12\x1c\n\x0b\x61pplication\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12G\n\x0frelease_channel\x18\x01 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12 \n\x18\x66orce_create_new_version\x18\x07 \x01(\x08J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\ncluster_idR\x0c\x63luster_name\"K\n\x1b\x43onfigureReleaseChannelResp\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1b\n\x13\x63reated_new_version\x18\x02 \x01(\x08\"\xb5\x01\n\x17\x44\x65leteReleaseChannelReq\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\x12\x1c\n\x0b\x61pplication\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"+\n\x18\x44\x65leteReleaseChannelResp\x12\x0f\n\x07version\x18\x01 \x01(\t\"-\n\x16ListReleaseChannelsReq\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\"]\n\x17ListReleaseChannelsResp\x12\x42\n\x10release_channels\x18\x01 \x03(\x0b\x32(.prodvana.release_channel.ReleaseChannel\"D\n\x14GetReleaseChannelReq\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\"Z\n\x15GetReleaseChannelResp\x12\x41\n\x0frelease_channel\x18\x01 \x01(\x0b\x32(.prodvana.release_channel.ReleaseChannel\"d\n\x1aGetReleaseChannelConfigReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xb7\x01\n\x1bGetReleaseChannelConfigResp\x12>\n\x06\x63onfig\x18\x01 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\x12G\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\"\xa4\x01\n\x1aGetReleaseChannelEventsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x1f\n\x17order_by_desc_timestamp\x18\x05 \x01(\x08\"^\n\x1bGetReleaseChannelEventsResp\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.prodvana.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xdd\n\n\x15ReleaseChannelManager\x12\xce\x01\n\x17\x43onfigureReleaseChannel\x12\x34.prodvana.release_channel.ConfigureReleaseChannelReq\x1a\x35.prodvana.release_channel.ConfigureReleaseChannelResp\"F\x82\xd3\xe4\x93\x02@\";/v1/applications/{application=*}/release-channels/configure:\x01*\x12\xb5\x01\n\x13ListReleaseChannels\x12\x30.prodvana.release_channel.ListReleaseChannelsReq\x1a\x31.prodvana.release_channel.ListReleaseChannelsResp\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/applications/{application=*}/release-channels\x12\xb6\x01\n\x14\x44\x65leteReleaseChannel\x12\x31.prodvana.release_channel.DeleteReleaseChannelReq\x1a\x32.prodvana.release_channel.DeleteReleaseChannelResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/release-channels/{release_channel=*}/delete\x12~\n\x15ListReleaseChannelsV2\x12\x30.prodvana.release_channel.ListReleaseChannelsReq\x1a\x31.prodvana.release_channel.ListReleaseChannelsResp\"\x00\x12\xc3\x01\n\x11GetReleaseChannel\x12..prodvana.release_channel.GetReleaseChannelReq\x1a/.prodvana.release_channel.GetReleaseChannelResp\"M\x82\xd3\xe4\x93\x02G\x12\x45/v1/applications/{application=*}/release-channels/{release_channel=*}\x12\xdc\x01\n\x17GetReleaseChannelConfig\x12\x34.prodvana.release_channel.GetReleaseChannelConfigReq\x1a\x35.prodvana.release_channel.GetReleaseChannelConfigResp\"T\x82\xd3\xe4\x93\x02N\x12L/v1/applications/{application=*}/release-channels/{release_channel=*}/config\x12\xdc\x01\n\x17GetReleaseChannelEvents\x12\x34.prodvana.release_channel.GetReleaseChannelEventsReq\x1a\x35.prodvana.release_channel.GetReleaseChannelEventsResp\"T\x82\xd3\xe4\x93\x02N\x12L/v1/applications/{application=*}/release-channels/{release_channel=*}/eventsBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.release_channel.release_channel_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _CONFIGURERELEASECHANNELREQ.fields_by_name['application']._options = None
  _CONFIGURERELEASECHANNELREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _DELETERELEASECHANNELREQ.fields_by_name['application']._options = None
  _DELETERELEASECHANNELREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETRELEASECHANNELCONFIGREQ.fields_by_name['application']._options = None
  _GETRELEASECHANNELCONFIGREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['application']._options = None
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['release_channel']._options = None
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELMANAGER.methods_by_name['ConfigureReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['ConfigureReleaseChannel']._serialized_options = b'\202\323\344\223\002@\";/v1/applications/{application=*}/release-channels/configure:\001*'
  _RELEASECHANNELMANAGER.methods_by_name['ListReleaseChannels']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['ListReleaseChannels']._serialized_options = b'\202\323\344\223\0023\0221/v1/applications/{application=*}/release-channels'
  _RELEASECHANNELMANAGER.methods_by_name['DeleteReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['DeleteReleaseChannel']._serialized_options = b'\202\323\344\223\0021*//v1/release-channels/{release_channel=*}/delete'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannel']._serialized_options = b'\202\323\344\223\002G\022E/v1/applications/{application=*}/release-channels/{release_channel=*}'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelConfig']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelConfig']._serialized_options = b'\202\323\344\223\002N\022L/v1/applications/{application=*}/release-channels/{release_channel=*}/config'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelEvents']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelEvents']._serialized_options = b'\202\323\344\223\002N\022L/v1/applications/{application=*}/release-channels/{release_channel=*}/events'
  _globals['_CONFIGURERELEASECHANNELREQ']._serialized_start=304
  _globals['_CONFIGURERELEASECHANNELREQ']._serialized_end=608
  _globals['_CONFIGURERELEASECHANNELRESP']._serialized_start=610
  _globals['_CONFIGURERELEASECHANNELRESP']._serialized_end=685
  _globals['_DELETERELEASECHANNELREQ']._serialized_start=688
  _globals['_DELETERELEASECHANNELREQ']._serialized_end=869
  _globals['_DELETERELEASECHANNELRESP']._serialized_start=871
  _globals['_DELETERELEASECHANNELRESP']._serialized_end=914
  _globals['_LISTRELEASECHANNELSREQ']._serialized_start=916
  _globals['_LISTRELEASECHANNELSREQ']._serialized_end=961
  _globals['_LISTRELEASECHANNELSRESP']._serialized_start=963
  _globals['_LISTRELEASECHANNELSRESP']._serialized_end=1056
  _globals['_GETRELEASECHANNELREQ']._serialized_start=1058
  _globals['_GETRELEASECHANNELREQ']._serialized_end=1126
  _globals['_GETRELEASECHANNELRESP']._serialized_start=1128
  _globals['_GETRELEASECHANNELRESP']._serialized_end=1218
  _globals['_GETRELEASECHANNELCONFIGREQ']._serialized_start=1220
  _globals['_GETRELEASECHANNELCONFIGREQ']._serialized_end=1320
  _globals['_GETRELEASECHANNELCONFIGRESP']._serialized_start=1323
  _globals['_GETRELEASECHANNELCONFIGRESP']._serialized_end=1506
  _globals['_GETRELEASECHANNELEVENTSREQ']._serialized_start=1509
  _globals['_GETRELEASECHANNELEVENTSREQ']._serialized_end=1673
  _globals['_GETRELEASECHANNELEVENTSRESP']._serialized_start=1675
  _globals['_GETRELEASECHANNELEVENTSRESP']._serialized_end=1769
  _globals['_RELEASECHANNELMANAGER']._serialized_start=1772
  _globals['_RELEASECHANNELMANAGER']._serialized_end=3145
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.organization.organization_manager_pb2

class OrganizationManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetOrganization: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationResp,
    ]
    GetOrganizationMetrics: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetricsReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetricsResp,
    ]
    GetOrganizationInsights: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationInsightsReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationInsightsResp,
    ]
    SnoozeOrganizationInsight: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.SnoozeOrganizationInsightReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.SnoozeOrganizationInsightResp,
    ]
    GetOrganizationMetadata: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetadataReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetadataResp,
    ]
    """Get org metadata, useful for constructing edit workflows for metadata"""
    SetOrganizationMetadata: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationMetadataReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationMetadataResp,
    ]
    GetUser: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetUserReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetUserResp,
    ]
    """Get a user in an organization, will return NOT_FOUND if the user is eitehr missing or not in an organization"""
    GetOrganizationSubscriptionStatus: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSubscriptionStatusReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSubscriptionStatusResp,
    ]
    GetOrganizationSettings: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSettingsReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSettingsResp,
    ]
    SetOrganizationSettings: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationSettingsReq,
        prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationSettingsResp,
    ]

class OrganizationManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetOrganization(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationResp: ...
    @abc.abstractmethod
    def GetOrganizationMetrics(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetricsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetricsResp: ...
    @abc.abstractmethod
    def GetOrganizationInsights(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationInsightsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationInsightsResp: ...
    @abc.abstractmethod
    def SnoozeOrganizationInsight(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.SnoozeOrganizationInsightReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.SnoozeOrganizationInsightResp: ...
    @abc.abstractmethod
    def GetOrganizationMetadata(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetadataReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationMetadataResp:
        """Get org metadata, useful for constructing edit workflows for metadata"""
    @abc.abstractmethod
    def SetOrganizationMetadata(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationMetadataReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationMetadataResp: ...
    @abc.abstractmethod
    def GetUser(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetUserReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetUserResp:
        """Get a user in an organization, will return NOT_FOUND if the user is eitehr missing or not in an organization"""
    @abc.abstractmethod
    def GetOrganizationSubscriptionStatus(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSubscriptionStatusReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSubscriptionStatusResp: ...
    @abc.abstractmethod
    def GetOrganizationSettings(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSettingsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.GetOrganizationSettingsResp: ...
    @abc.abstractmethod
    def SetOrganizationSettings(
        self,
        request: prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationSettingsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.organization.organization_manager_pb2.SetOrganizationSettingsResp: ...

def add_OrganizationManagerServicer_to_server(servicer: OrganizationManagerServicer, server: grpc.Server) -> None: ...
